import { hopeTheme } from "vuepress-theme-hope";
import { enNavbar } from "./navbar/index.js";
import { enSidebar } from "./sidebar/index.js";

const hostname =
  process.env["HOSTNAME"] || "https://2023.igem.wiki";

export default hopeTheme(
  {
    hostname,

    iconAssets: [
      "/bjwz-china/assets/css/brands.min.css",
      "/bjwz-china/assets/css/fontawesome.min.css",
      "/bjwz-china/assets/css/solid.min.css",
    ],

    logo: "/logo.svg",

    favicon: "/favicon.ico",

    docsDir: "src",

    toc: false,

    breadcrumb: false,

    locales: {
      "/": {
        // navbar
        navbar: enNavbar,

        // sidebar
        sidebar: enSidebar,

        footer: "© 2023 - Content on this site is licensed under a Creative Commons Attribution 4.0 International license.",

        displayFooter: true,

        editLink: false,

        contributors: false,

        lastUpdated: false,

      },
    },

    plugins: {
      seo: false,
      sitemap: false,
      components: {
        components: [
          "ArtPlayer",
          "PDF",
        ],
      },
      mdEnhance: {
        align: true,
        attrs: true,
        card: true,
        chart: false,
        codetabs: true,
        demo: true,
        echarts: true,
        figure: true,
        flowchart: true,
        footnote: true,
        gfm: true,
        imgLazyload: true,
        imgSize: true,
        include: true,
        katex: true,
        mathjax: false,
        mark: true,
        mermaid: true,
        playground: {
          presets: ["ts", "vue"],
        },
        presentation: ["highlight", "math", "search", "notes", "zoom"],
        stylize: [
          {
            matcher: "Recommended",
            replacer: ({ tag }) => {
              if (tag === "em")
                return {
                  tag: "Badge",
                  attrs: { type: "tip" },
                  content: "Recommended",
                };
            },
          },
        ],
        sub: true,
        sup: true,
        tabs: true,
        vPre: true,
        vuePlayground: true,
      },
    },
  },
  { custom: true }
);
