---
title: Description
icon: fa-solid fa-bookmark
category: Project
tag:
  - Project
  - Description
next: ../project/design.md
---

![](https://static.igem.wiki/teams/4657/wiki/assets/images/description.png)

## The Problem
Cutibacterium acnes, the primary bacterium responsible for acne, not only causes post-inflammatory pigmentation spots and acne scars but also triggers inflammation in most adolescents throughout the prolonged course of the disease.

According to the questionnaire we produced, 90.32% of people around us have had acne. When asked about their attitude towards acne, 25.40% of people thought it was super annoying, 18.95% of people hated it, 23.79% thought it was a little annoying, and these people accounted for 68.14% of the total, more than half of the total.

::: echarts People's Attitude towards The Acne

```js
option = {
  legend: {
    top: 'bottom'
  },
  tooltip: {
    trigger: 'item'
  },
  series: [
    {
      name: 'Nightingale Chart',
      type: 'pie',
      radius: [20, 100],
      center: ['50%', '50%'],
      roseType: 'area',
      itemStyle: {
        borderRadius: 8
      },
      data: [
        {
          "value": 25.4,
          "name": "Super Annoying"
        },
        {
          "value": 23.79,
          "name": "A Little Annoying"
        },
        {
          "value": 18.95,
          "name": "Hate It"
        },
        {
          "value": 16.94,
          "name": "It is Normal"
        },
        {
          "value": 13.31,
          "name": "No Feelings About It"
        },
        {
          "value": 1.61,
          "name": "Other"
        }
      ]
    }
  ]
};
```

:::

We also analyzed the problems caused by acne. According to our survey, acne has caused facial anxiety to 70.56% of people around us, 62.50% of people have facial discomfort. It also caused other problems such as social disorders and inferiority complex. Only 18.95% people think it doesn't cause any trouble.

::: echarts The Problems Caused by Acne

```js
option = {
  tooltip: {
    trigger: 'item'
  },
  series: [
    {
      name: 'Access From',
      type: 'pie',
      radius: '50%',
      data: [
        { value: 70.56, name: 'Facial Anxiety' },
        { value: 62.5, name: 'Facial Discomfort' },
        { value: 16.73, name: 'Treatment Costs Money' },
        { value: 11.69, name: 'Difficulty Concentration' },
        { value: 33.06, name: 'Inferiority Complex' },
        { value: 14.11, name: 'Inconvenient to Make up' },
        { value: 2.42, name: 'Other Problems' },
        { value: 18.95, name: 'No Problems' }
      ],
      emphasis: {
        itemStyle: {
          shadowBlur: 10,
          shadowOffsetX: 0,
          shadowColor: 'rgba(0, 0, 0, 0.5)'
        }
      }
    }
  ]
};
```
:::

To sum up, we think acne is a common problem in the population, and not just among teenagers. Although the exact pathogenesis of acne has not been fully elucidated, existing data suggest that there are multiple factors contributing to its development, including genetic predisposition, excessive sebum production, abnormal keratinization of hair follicle sebaceous ducts, proliferation of Cutibacterium acnes, inflammation, and immune reactions. Common treatment methods for acne include topical medications, systemic drugs, phototherapy, chemical peels, and microneedle therapy. Topical medications often involve the use of antibiotics (such as erythromycin) or antimicrobial agents (such as tretinoin), which can achieve certain therapeutic effects but may lead to bacterial resistance and side effects such as skin itching and redness[^first]. Although laser therapy for acne yields quick results, it is associated with strong adverse reactions such as pain, erythema, and pigmentation changes. Other methods have shown some efficacy but have not adequately addressed issues related to cost-effectiveness, treatment duration, and convenience[^second][^third]. In recent years, the understanding of the role played by Cutibacterium acnes in the pathophysiology of acne has undergone transformation, and the imbalance in the skin microbiome has also been implicated in its occurrence[^forth]. This discovery may provide new perspectives for future acne treatments. Therefore, it is evident that acne development involves multiple factors and mechanisms, and actively seeking safe, effective, and reliable treatment methods remains a hot topic in acne management. 

>Let's watch our promotion video to see the example.

<ArtPlayer
  src="https://video.igem.org/download/streaming-playlists/hls/videos/28861c7d-7d7f-4279-a7c4-b1fa21b05659-1080-fragmented.mp4"
  poster="https://static.igem.wiki/teams/4657/wiki/assets/images/promotion-video-cover.png"
  auto-size
/>

## Our Inspiration
Knowing that so many people suffer from acne, and that we suffer from it ourselves, we decided to find a cure. According to the research, porphyrins secreted by Cutibacterium acnes have been identified as the main factor contributing to acne inflammation. Furthermore, this possesses pathways for both porphyrin and vitamin B12 synthesis with shared precursors. When there is more vitamin B12 in the outside environment, the bacteria themselves will obtain vitamin B12 from the outside world and reduce vitamin B12 synthesis, and instead synthesize more porphyrins. Porphyrins are secreted into the external environment, triggering inflammation that leads to acne[^fifth].

![Cutibacterium acnes in its normal state.](https://static.igem.wiki/teams/4657/wiki/assets/images/contents/description/des3.png)

## Our Solution

We designed the experimental project based on the above principles, and hope to have a certain therapeutic effect on acne.

For this purpose, BJWZ-China utilized arabinose operon in E.coli to regulate the expression of a vitamin B12 transporter called BtuB, maximizing VB12 absorption from the surroundings.

![A schematic of how our engineered bacteria work.](https://static.igem.wiki/teams/4657/wiki/assets/images/contents/description/des4.png)

![The protein we used, BtuB, is a vitamin B12 transporter.](https://static.igem.wiki/teams/4657/wiki/assets/images/contents/description/des5.png)

Reducing the level of vitamin B12 in the environment can effectively decrease porphyrin production and alleviate inflammation.

![We envision the effect to be achieved.](https://static.igem.wiki/teams/4657/wiki/assets/images/contents/description/des6.png)

Additionally, lactose operon used to control MazEF and ccdB toxin protein expression, can ensure maintenance of biosafety measures. 

![Schematic diagram of how the suicide system works.](https://static.igem.wiki/teams/4657/wiki/assets/images/contents/description/des7.png)

This project focuses on addressing concerns related to acne treatment among teenagers while seeking more stable and long-lasting solutions based on skin microbiome conditions.

## Our Goal
We hope to achieve two main desired effects through this project.
First, we hope that engineered bacteria could be put into facial care and treatment products to absorb excessive vitamin B12 on the face, to achieve the effect of reducing inflammation, thereby reducing the occurrence of acne.

In addition, due to the high tolerance of the selected chassis strain to VB12, we aim to maximize its utility by enabling it not only absorb and VB12 in acne surroundings but also release it through other protein channels when needed by the body, thereby maintaining a relatively stable microenvironment of VB12 at the lesion site. This means that when the engineered bacteria have done their job on the human face, they can be recycled and put to more use, thereby contributing to sustainable development.

We hope to be able to achieve both goals through experiments and contributing to others.

## Reference

[^first]: 李文锐, 林麟. 外用维 A 酸治疗皮肤病的进展 [J]. 国际皮肤性病学杂志，2017，43(3): 133-136

[^second]: 夏栩琼, 徐慧, 陆雯丽, 等. 30％超分子水杨酸治疗寻常痤疮的疗效观察[J]．中国皮肤性病学杂志, 2019, 33 (5): 616-619

[^third]: Alessia Villani, Maria Carmela Annunziata, Maria Antonietta Luciano, Gabriella Fabbrocini, et al. Skin needling for the treatment of acne scarring: a comprehensive review [J]. J Cosmet Dermatol, 2020, 19 (9): 2174-2181

[^forth]: Chun-Xi Li, Zhi-Xuan You, Yan-Xia Lin, Hai-Yue Liu, Jin Su, et al. Skin microbiome differences relate to the grade of acne vulgaris [J]. J Dermatol, 2019, 46 (9): 787-790

[^fifth]: Kang D, Shi B, Erfe MC, Craft N, Li H. Vitamin B12 modulates the transcriptome of the skin microbiota in acne pathogenesis. Sci Transl Med. 2015 Jun 24;7(293):293ra103. doi: 10.1126/scitranslmed.aab2009. PMID: 26109103; PMCID: PMC6049814.
