---
title: Engineering
icon: fa-solid fa-vial
category: Project
tag:
  - Project
  - Engineering
prev: ../project/design.md
next: ../project/results.md
---

![](https://static.igem.wiki/teams/4657/wiki/assets/images/engineneering.png)

## I. Introduction
Acne is a chronic inflammatory skin disease of the follicular sebaceous gland unit, which mainly occurs in adolescents and has a great psychological and social impact on adolescents. At present, the known causes of acne include excessive sebum secretion, blockage of hair follicle sebaceous duct, bacterial infection and inflammatory reaction, etc. According to the research, we know that too much vitamin B12 also has a probability of causing acne. At present, porphyrins are known to cause inflammation. Vitamin B12 and porphyrins are substances required for the survival of *Cutibacterium acnes*. They share the same precursor when synthesized in *Cutibacterium acnes*, which means that there is an antagonistic relationship between them. When the concentration of vitamin B12 in the external environment is high, *Cutibacterium acnes* can directly obtain vitamin B12 from the surroundings. At this time, the synthesis of vitamin B12 in the strain will decrease, and the synthesis of porphyrin will increase, and when excessive porphyrin is discharged into the external environment, it will cause inflammation, resulting in acne. We have designed an engineered bacterium that can absorb vitamin B12 from the face, and hope that it can relieve inflammatory acne caused by porphyrins.

## II. Experimental Materials
In this study, the target plasmid was constructed in vitro, and the required plasmid was expanded in *Escherichia coli* DH5α, and related transformation was carried out by thermal hot shock transformation. After obtaining the target plasmid, MG1655 strain was transformed, and the target mutants were screened by colony PCR and enzyme digestion verification. The strains and reagent materials involved in this study are as follows:

### 1. Strains and Plasmids
The chassis strain we used was MG1655, which was used in the laboratory to synthesize vitamin B12, so it had a high tolerance to vitamin B12. There was no need to worry about the absorption of excessive vitamin that leads to the weakening of bacterial activity. DH5α was used to amplify the target plasmid efficiently.

###### Table 1: Strains and Plasmids Used in this Study
| Name | Functional Description	| Source |
| -- | -- | -- |
| E.coli DH5α | Amplification of target plasmid | 2nd Lab® |
| MG1655 | Basidiomycete | 2nd Lab® |
| pBS | Vector Plasmid | AZENTA |
| pET-28a(+) | Vector Plasmid | AZENTA |
| pACYC184 | Vector Plasmid | AZENTA |
| pSuicide | Provide ccdB gene | BNU-China |

### 2. Plasmid
Three plasmids, pBS, pET-28a (+) and pACYC184, were used in this study.

For the pBS plasmid, we inserted the *E. coli btuB* gene and regulated its expression with arabinose operon. BtuB is a transmembrane protein, which has the ability to transport vitamin B12 into cells. We hope to achieve its active and efficient absorption of vitamin B12 by artificially regulating the expression of this protein in *E. coli* For the pET-28a (+) plasmid, we inserted a commonly used suicide gene *ccdB* and regulated its expression with lactose operons to artificially manipulate bacterial suicide and ensure no possibility of environmental leakage. The suicide gene *ccdB* fragment, with Sac II restriction site at the 5 'end and EcoR I restriction site at the 3' end, was inserted into the plasmid pACYC184 to obtain the recombinant suicide plasmid pACYC184-ccdB

### 3. Experimental Reagents and Media

We used LB medium and added antibiotics and expression inducers as needed. The full list is as follows:

###### Table 2: Experimental Reagents
|Reagent name|Manufacturer|
|--|--|
|Restriction endonuclease|TaKaRa|
|T4 DNA Ligase|TaKaRa|
|In-Fusion HD Cloning kit|TaKaRa|
|Ex-Taq DNA polumersase|TaKaRa|
|dNTP|TaKaRa|
|DNA Marker|TaKaRa|
|PCR Mix|TIANGEN|
|Plasmid extraction kit|Magen|
|PCR product recovery kit|Magen|
|GeneJET agarose gel recovery kit|Magen|
|Ampicillin, sodium salt|Sangon Biotech|
|Kanamycin sulfate|Sangon Biotech|
|50×TAE|Sangon Biotec|
|Vitamin B12|SAITONG|
|LB Broth|BeSebio|
|LB Agar|BeSebio|
|VitaminB12 ELISA kit|JINGMEI|

#### Medium
LB medium: Weigh 40 g of LB Agar or 20 g of LB Broth powder, stir with 800 mL distilled water, dissolve the medium, hold the medium to 1 L, and sterilize, 121 ℃, 20 min.

#### Antibiotics
The storage concentration of ampicillin was 50 mg/mL and the working concentration was 100 μg/mL, stored at -20 ℃. Kanamycin sulfate and tetracycline solution with a concentration of 100 mg/mL and a working concentration of 50 μg/mL were stored at -20 ℃.

## III. Experimental Methods

### 1. Culture and Preservation of *E. coli*
The sterilize 50% glycerin was divided into 2 mL frozen storage tubes after sterilization in a super-clean bench, each tube was 1 mL, loosen the cap and sterilized again,then refrigerate at 4 ℃ for use. The target strains were inoculated into 5 mL LB liquid medium containing corresponding antibiotics at 200 rpm, cultured overnight at 37 ℃, at 5000 rpm, centrifuged for 5 min, abandoned the supernatant, and then added to 1mL fresh antibiotic-free LB medium to reinsert the bacteria at 5000 rpm. Centrifuge for 5 min, wash the bacteria and discard the supernatant, then add 1 mL fresh LB medium, reinsert the bacteria, add all of them into the frozen storage tube, mix them upside down, label the strain name, resistance, production time and producer, and freeze them in the refrigerator at -80 ℃. Prepare the corresponding resistance LB solid plate, dry the condensation of water on the surface of the plate to prevent the formation of bacterial moss after the water flow through the colony during inoculation. A small amount of bacterial solution was obtained from the glycerol tube with a sterilized inoculation ring, and then activated on a plate with a line. After the bacterial colonies grew out, a single colony was selected and transferred to LB medium containing corresponding antibiotics at 200 rpm and cultured overnight at 37 ℃.

### 2. Transformation of *E. coli*
*E. coli* competent cells were purchased from 2nd Lab® for 100 µL per tubes, and the specific transformation steps were as follows:

- Take out the competent cells from the  -80 ℃ refrigerator, put them on ice and wait until they dissolved, then add the appropriate amount of target DNA fragments into the competent cells, gently flick the tip of the finger tube to mix well, and incubate on ice for 20 - 30 min;
- After the ice incubation, the mixture was hot shocked at 42 ℃ for 90 s, then quickly placed it on ice and left the mixture to stand for 2 min. 900 µL of fresh LB liquid medium preheated at 37 ℃ was added to the mixture, and it was resuscitated for 1 hour at 37 ℃ and 160 rpm;
- After recovery, centrifuge at 5000 rpm for 5 min, discard the supernatant, resuspend the organisms with 500 µL of fresh medium, take 100 µL of the bacterial solution and spread it on the LB plate containing the corresponding antibiotics, and incubate at 37 ℃ overnight.

### 3. Colony PCR
- After the transformants coated in step 3.2 are cultured overnight until the colony diameter is 0.5 mm, colony PCR can be performed;
- Prepare PCR tubes, primers, another new plate, primers, pipette tips and PCR Mix, etc., and prepare the appropriate system on the lab bench;
-Scraping a small amount of single colony with a white pipette tip in the super-clean bench, stir gently in the PCR system for 5~10 times, and then put the tip on the prepared plate with the same antibiotic added, and mark it accordingly, and cultivate it under the corresponding conditions;
- Determine the correct transformants according to the agarose gel electrophoresis results of PCR products, and then line purification;
- Inoculate the purified transformants into 5 mL of LB medium with appropriate antibiotics, incubate overnight and extract the plasmids, quantify by agarose gel electrophoresis, and then perform enzyme digestion for verification;
- Expand the culture of the correctly verified transformants and preserve them in glycerol tubes.

### 4 Enzymatic Digestion, Ligation and PCR System
The digestion reaction is used to verify whether the target plasmid is connected correctly, generally use single or double digestion; digestion template needs to be determined according to the size of the target bands, generally 10 μL system digestion 200~300 ng

###### Table 3: Enzyme Digestion Reaction System
|Reagent Name|Reagent Dosage|
|--|--|
|Enzyme A|2 μL|
|Enzyme B|2 μL|
|10× Enzyme Cutting Buffer|1 μL|
|Template|200 ng|
|RNase-free ddH2O|Add up to 10 μL|

The target fragment was ligated with the digested vector, and the product after the In-Fusion ligation reaction was transformed in *E. coli*, ligating 10 μL of the system as follows:

###### Table 4: Ligation System of Gene Fragments and Vector Plasmids
|Reagent Name|Reagent Dosage|
|--|--|
|Linearized plamid AGE recycling products|A µL (200 ng)|
|Template|B μL (100 ng)|
|5×In-Fusion HD|2 μL|
|Aseptic ddH2O|Add up to 10 μL|

Mix the system in the PCR tube, briefly centrifuged and placed in the PCR instrument at 50 ℃ for 15 min. At the end of the reaction, remove the  5 μL product for *E. coli* transformation.

The amount of conventional PCR template is 100 ng, and the system is 20 mL; in the case of colony PCR, the enzyme, buffer and dNTP in the system are included in the PCR Mix.

###### Table 5: Common PCR Reaction System
|Reagent name|Reagent dosage|
|--|--|
|10×Ex-taq buffer|2 μL|
|dNTP|2 μL|
|Primer-F/R|1/1 μL|
|Template|1 μL|
|Enzyme|0.2 μL|
|RNase-free ddH2O|Add up to 20 μL|

The temperature and time of the PCR program were determined based on the enzyme used and the length of the PCR and the annealing temperature of the primers.

###### Table 6: Reaction Procedures of PCR
![](https://static.igem.wiki/teams/4657/wiki/assets/images/contents/results/tb6.png)

## IV. Experimental Procedure

### 1. Gene Sequence Search
The gene *btuB* sequence of *E.coli* MG1655 was obtained by reviewing the literature, and download from NCBI (Gene symbol: btuB; [Gene ID: 948468](https://www.ncbi.nlm.nih.gov/gene/948468)).
 
### 2. Sequence Synthesis and Construction of Expression Plasmid
The degradation of arabinose in *E. coli* requires three genes :araB, araA and araD, which form a gene cluster, abbreviated *araBAD*; Arabinose promoter, ribosome binding site, *araBAD* and *btuB* were fused into a fragment, namely: expression of *btuB*. In addition, the synthesis of *araC* gene is required to regulate the transcription of araBAD when arabinose is added.

The expression of the synthesized fragment was *araC*, with the 5 'end retaining the Xba I restriction site and the 3' end retaining the Sac I restriction site. The fragment was inserted into the carrier plasmid pBS to obtain the recombinant plasmid pA. In the expression of *btuB*, Xba I restriction site was retained at the 5 'end and Xho I restriction site was retained at the 3' end. The fragment was inserted into pA to obtain the recombinant plasmid pBS-BADpromoter-btuB, which could be used to express BtuB in MG1655.
   
The *ccdB* gene in pSuicide given by BNU-China 2023 was used as a reference sequence, and its temperature-sensitive suicide switch was retained, while the EcoR I cleavage site was retained at the 5 'end and the Hind III cleavage site was retained at the 3' end. After the gene was transferred to the company for sequence optimization, it was connected to the carrier pACYC184. Then the target plasmid pACYC184-ccdB was obtained. In theory, in the human body environment, the temperature is about 37 ℃; Once the bacteria leak into the environment, the switch is turned on by temperatures either above or below 37 ℃, causing it to commit suicide.
  
We turned to use pACYC184-ccdB as a template to amplify the optimized *ccdB* gene, which no longer retains its temperature-controlled switch and replaced as a lactose manipulator to regulate the expression of *ccdB*. In-Fusion primers were designed to retain the EcoR I cleavage site at the 5' end and the Hind III cleavage site at the 3' end of the gene, and fused into the same digestion linearized pET-28a(+) vector which digest to obtain the target suicide plasmid pET-28a(+)-ccdB.    

 
### 3. The Target Strains were Obtained
After *E. coli* transformation, colony PCR and enzyme digestion verification, we obtained the target strain MG1655+btuB+ccdB successfully transferred it into pBS-BADpromoter-btuB and pET-28a (+) -ccdB plasmid, abbreviated as Mbc.
 
### 4. To Explore the Optimal Concentration of Arabinose induced btuB Expression
Single colonies of strain Mbc were inoculated in 5 mL LB medium with ampicillin and kanamycin, cultured overnight, and then transferred to a new 20 mL medium for culture to OD600=0.6.
   
Seven 50 mL conical bottles containing 20 mL LB liquid culture medium were prepared from the same batch, and arabinose mother liquor was added to filter and remove bacteria, so that the final concentration (mass to volume ratio: m/v) was 0,0.1%, 0.2%, 0.3%, 0.4%, 0.5%, 0.6%, respectively.
    
Then the initial bacterial solution with OD600=0.6 was inoculated at 2% of the medium volume and cultured at 37 ℃ at 200 rpm for 12h. On the second day, 3mL bacterial solution was taken to measure OD600 to confirm that the addition of arabinose would not inhibit the growth of Mbc.
Subsequently, we centrifuged the bacterial suspension, collected the bacteria, and commissioned the company to measure the mRNA expression of *btuB* gene in order to obtain the optimal induced concentration of arabinose.
 
### 5. To Explore the Optimal Timing and Concentration of IPTG-induced ccdB Expression
Single colonies of strain Mbc were inoculated in 5 mL LB medium with ampicillin and kanamycin, cultured overnight, and then transferred to a new 20 mL medium for culture to OD600=0.6.
   
Eight 50 mL flasks containing 20 mL LB liquid medium prepared from the same batch were added with filtrated and sterilization IPTG to make their final concentrations 0,0.2, 0.4, 0.6, 0.8, 1.2, 1.4mmol/L, respectively, and cultured at 37 ℃ at 200 rpm at 2% of the medium volume. Then 100 μL was taken every 1h and coated on the culture-medium with the appropriate antibiotic for 8h.
   
On the second day, the number of colonies on the medium was observed and photographed to make a comparison map, so as to find the optimal induction time and concentration.

## V. Results

::: info Redirect to Results Page

This part is available at [Results](../project/results.md) page.

:::

## VI. Conclusion
We successfully constructed the expression plasmid of BtuB protein which could transport VB12 into cells, and verified that the gene could indeed be expressed in the MG1655 by qRT-PCR. In addition, the suicide plasmid system we used to ensure biosafety also functioned well, achieving controlability of experimental operation and meeting the requirements of iGEM.

## VII. Next Steps

### 1. Determination of Vitamin B12 Absorption Effect
Our next plan is to measure the vitamin B12 uptake of the target strain; set up different vitamin B12 concentration gradients and time gradients,  and measure the amount of vitamin B12 residue in the culture medium or the amount of vitamin B12 in the cells using JINGMEI's Vitamin B12 ELISA kit and referring to its instruction manual. In addition, we have prepared a standard sample for vitamin B12, which can also be used in high-performance liquid chromatography (HPLC) to measure cellular uptake of vitamin B12[^first].

![Schematic diagram of the kit.](https://static.igem.wiki/teams/4657/wiki/assets/images/contents/results/eg7-1.jpg)
> The kit was from <http://www.jsjmsw.com/cp_view.asp?id=54211>

The collected data will be processed and mathematical model constructed to evaluate the ability of the engineered bacteria’s ability of absorbing vitamin B12, which provides a powerful guide for the optimization of the subsequent acne elimination product design.

### 2.  Vitamin B12 Recovery
Bacteria in acne lesions synthesize and metabolize vitamin B12, in order to enable the bacteria or cells in the lesions to maintain the homeostasis of vitamin B12 in the environment when the microenvironment is imbalanced through the targeted adjustment of our products, so that the synthesis and secretion of porphyrin can reach a healthy state, and do not trigger a serious inflammatory response. Besides, we also plan to remove the vitamin B12 that has been absorbed into the engineered bacteria into our product carrier. 

BacA is a vitamin B12 transport ATP-binding protein which is capable to transfer vitamin B12 from intracellular to extracellular, and we plan to use a tryptophan manipulator to control expression of bacA.

### 3. Enhancement of btuB Expression
To enhance the uptake of vitamin B12 by the engineered bacteria, we plan to modify the plasmid btuB to express the tonB gene in a fusion with its existing base. The expressed protein TonB is a cytoplasmic membrane protein that delivers proton motive force from the cytoplasmic membrane to btuB, providing energy for vitamin B12 transmembrane transport, in order to improve the efficiency of vitamin B12 transport.

## VIII. Discussion

### 1. The Significance of the Successful Construction of Mbc for Acne Treatment
Nowadays, acne is one of the most common problems in the population. There is not yet a very effective solution, the construction of the engineered bacterium provides a new idea for the treatment of acne, and innovatively engineered the bacterium to target the pathway of Propionibacterium acnes for the synthesis of vitamin B12, which can alleviate the acne by decreasing the occurrence of inflammation.
    
The engineered bacteria are safe enough not to spread to the environment because of a robust suicide system and a fully controllable mechanism to regulate the expression of the target protein.

We look forward to contributing to the treatment of acne, reducing the appearance anxiety and low self-esteem caused by acne, and leaving people with better memories of their youth.

### 2. Significance of Recycling Vitamin B12

We constructed the plasmid of vitamin B12 for recycling, and then recycled it after functioning, in order to contribute to sustainable development. We also intend to reduce the waste of resources, let vitamin B12 work in more suitable places, including disease treatment, etc., to maximize the benefits, let synthetic biology enter into the public's view, and bring more convenience to our lives.

## IX. Reference

[^first]: 李贻, 王晓洁, 卞菲菲等. 高效液相色谱法检测婴幼儿配方食品中维生素B12的含量[J].食品安全质量检测学报, 2021,12(08):3306-3312.DOI:10.19812/j.cnki.jfsq11-5956/ts.2021.08.049.
