---
title: Model
icon: fa-solid fa-square-root-variable
category: Project
tag:
  - Project
  - Model
prev: ../project/results.md
next: ../project/parts.md
---
![](https://static.igem.wiki/teams/4657/wiki/assets/images/model.png)
## I. Overview
In this study, we modeled the induction effects of arabitol concentration on btuB and lactose concentration on ccdB, referring to previous iGEM projects[^first].

The purpose of building this system model is to determine the optimal lactose and arabitol concentrations for culturing our engineered strain Mbc.

You can find detailed design and construction processes of the plasmid [here.](../project/design.md)

## II. Reactions

### 1. btuB Reactions
The process of arabitol induction on btuB is as follows:

![](https://static.igem.wiki/teams/4657/wiki/assets/images/contents/model/dn1.png)
![](https://static.igem.wiki/teams/4657/wiki/assets/images/contents/model/dn2.png)

To simplify the calculations, we make the following assumptions:
 - a1. We assume that there are no external factors affecting Mbc, such as humidity, temperature, or other bacteria that consume arabitol.
 - a2. We assume that arabitol is uniformly distributed inside and outside Mbc. Since arabitol can diffuse through the cell wall and membrane, maintaining concentration equilibrium, we ignore the steps describing arabitol uptake and utilization and simply assume that the arabitol concentration inside Mbc is equal to the external concentration.
 - a3. In the model, the concentration of AraC is assumed to be fixed and sufficient.
 - a4. To simplify the model, we consider the process of btuB being transcribed from mRNA to expressed on the cell membrane as a whole.
 - a5. It is assumed that arabitol rapidly binds to AraC, and the resulting AA complex quickly binds to the binding site on the promoter, reaching equilibrium in a negligible amount of time.

Based on these assumptions, we have the following three separate reactions:

$$
\text{AraC + Ara} \xrightleftharpoons[k_{\text{A}_{\text{1}}}']{k_{\text{A}_{\text{1}}}} \text{AA}
\tag{A1}
$$
$$
\text{BIN + AA} \xrightleftharpoons[k_{\text{A}_{\text{2}}}']{k_{\text{A}_{\text{2}}}} \text{BAA}
\tag{A2}
$$
$$
\text{BAA} \xrightarrow{k_{\text{A}_{\text{3}}}} \text{btuB} \xrightarrow{k_{\text{A}_{\text{3}}}'} {\text{btuB}\phi}
\tag{A3}
$$

Reaction A1 describes the formation of AraC-Ara complex by the binding of AraC and arabitol, where $\text{AraC}$ represents the concentration of the protein AraC, $\text{Ara}$ represents the concentration of arabitol, $k_{\text{A}_{\text{1}}}$ represents the binding rate, $k_{\text{A}_{\text{1}}}'$ represents the dissociation rate, and $\text{AA}$ represents the concentration of the AraC-Ara complex.

Reaction A2 describes the binding of the specific binding site with the AraC-Ara complex to form the specific binding site × AraC-Ara complex, where $\text{BIN}$ represents the concentration of the binding site, $k_{\text{A}_{\text{2}}}$ represents the binding rate, $k_{\text{A}_{\text{2}}}'$ represents the dissociation rate, and $\text{BAA}$ represents the concentration of the specific binding site × AraC-Ara complex.

Reaction A3 describes the influence of the specific binding site × AraC-Ara complex on mRNA transcription and translation into protein expression. $k_{\text{A}_{\text{3}}}$ represents the rate of the entire process, $k_{\text{A}_{\text{3}}'}$ represents the degradation rate of the entire process, $\text{btuB}$ represents the expression level of btuB, and ${\text{btuB}\phi}$ represents the degradation level of btuB.

Using the law of mass action, we can convert them into three ODE:

$$
\dfrac{d\text{AA}}{dt} = {k_{\text{A}_{\text{1}}}} \cdot \text{Ara} - {k_{\text{A}_{\text{1}}}'} \cdot \text{AA}
\tag{A4}
$$
$$
\dfrac{d\text{BAA}}{dt} = {k_{\text{A}_{\text{2}}}} \cdot \text{BIN} \cdot \text{AA} - {k_{\text{A}_{\text{2}}}'} \cdot \text{BAA}
\tag{A5}
$$
$$
\dfrac{d\text{btuB}}{dt} = {k_{\text{A}_{\text{3}}}} \cdot \text{BAA} - {k_{\text{A}_{\text{3}}}'} \cdot \text{btuB}
\tag{A6}
$$

A4 relates the change in $\text{Ara}$ to the rate of change of $\text{AA}$.

A5 relates the changes in $\text{AA}$ and $\text{BIN}$ to the rate of change of $\text{BAA}$.

A6 relates the rate of change of btuB to the changes in $\text{BAA}$.

Based on assumption a5, we simplify the equations using the quasi-steady-state approximation (QSSA).

By substituting the rate of change of A1 with 0, we can obtain:

$$
0 = \dfrac{d\text{AA}}{dt} = {k_{\text{A}_{\text{1}}}} \cdot \text{Ara} - {k_{\text{A}_{\text{1}}}'} \cdot \text{AA}
$$
$$
\text{AA} = \dfrac{k_{\text{A}_{\text{1}}} \cdot \text{Ara}}{k_{\text{A}_{\text{1}}}'}
\tag{A7 - 1}
$$

Here, we let

$$
{K_{\text{A}_{\text{1}}}} = \dfrac{k_{\text{A}_{\text{1}}}'}{k_{\text{A}_{\text{1}}}}
$$

which gives us:

$$
\text{AA} = \dfrac{\text{Ara}}{K_{\text{A}_{\text{1}}}}
\tag{A7 - 2}
$$

Thus, we obtain $\text{AA}$.

In A2, we want to obtain $\text{BAA}$. Before that, we can eliminate BIN by using the relationship:

$$
\text{Free Promoter} = \text{Total Promoter} - \text{Bound Promoter}
$$

which gives us:

$$
\text{BIN} = \text{CNP} - \text{BAA}
$$

To eliminate the BIN to simplify the equation, and here $\text{CNP}$ stands for the Copy Number of Plasmids.

Substituting this back into A2 and using QSSA with the rate of change as 0, we get:

$$
0 = \dfrac{d\text{BAA}}{dt} = {k_{\text{A}_{\text{2}}}} (\text{CNP} - \text{BAA}) \cdot \text{AA} - {k_{\text{A}_{\text{2}}}'} \cdot \text{BAA}
\tag{A8 - 1}
$$

Similarly, we let

$$
{K_{\text{A}_{\text{2}}}} = \dfrac{k_{\text{A}_{\text{2}}}'}{k_{\text{A}_{\text{2}}}}
$$

which gives us:

$$
\text{BAA} = \dfrac{\text{AA} \cdot \text{CNP}}{AA + K_{\text{A}_{\text{2}}}}
\tag{A8 - 2}
$$

Finally, by substituting the above results into A3 and using QSSA, we get:

$$
\text{BAA} = \dfrac{\text{AA} \cdot \text{CNP}}{AA + K_{\text{A}}} = \dfrac{\text{Ara} \cdot \text{CNP}}{\text{Ara} + {K_{\text{A}_{\text{1}}}} \cdot {K_{\text{A}_{\text{2}}}}}
$$
$$
\dfrac{d\text{btuB}}{dt} = {k_{\text{A}_{\text{3}}}} \cdot \text{BAA} - {k_{\text{A}_{\text{3}}}'} \cdot \text{btuB}
\tag{A6}
$$
$$
0 = \dfrac{k_{\text{A}_{\text{3}}} \cdot \text{Ara} \cdot \text{CNP}}{\text{Ara} + {K_{\text{A}_{\text{1}}}} \cdot {K_{\text{A}_{\text{2}}}}} - {k_{\text{A}_{\text{3}}}'} \cdot \text{btuB}
$$
$$
\text{btuB} = \dfrac{k_{\text{A}_{\text{3}}} \cdot \text{Ara} \cdot \text{CNP}}{k_{\text{A}_{\text{3}}}' ( \text{Ara} + {K_{\text{A}_{\text{1}}}} \cdot {K_{\text{A}_{\text{2}}}} ) }
\tag{A9} + \alpha
$$

$\alpha$ is the concentration of btuB protein outside this plasmid in Mbc.

which represents the equations of the btuB Reactions model.

### 2. ccdB Reactions

The process of lactose induction of ccdB is as follows:

![](https://static.igem.wiki/teams/4657/wiki/assets/images/contents/model/dn3.png)
![](https://static.igem.wiki/teams/4657/wiki/assets/images/contents/model/dn4.png)

Similarly, to simplify the calculations, we make the following assumptions:
- a1: We assume that there are no external factors affecting Mbc, such as humidity, temperature, or other lactose-consuming bacteria.
- a2: We assume that lactose is uniformly distributed inside and outside Mbc. Since lactose can diffuse through the cell wall and membrane, maintaining concentration equilibrium, we ignore the steps describing the uptake and utilization of arabinose and simply assume that the lactose concentration inside Mbc is equal to the external concentration.
- a3: In the model, the concentration of the protein tetramer is assumed to be constant and sufficient.
- a4: It is assumed that the protein tetramer forms instantaneously, and lactose rapidly binds to the tetramer, reaching equilibrium in a negligible amount of time.
- a5: The concentration of the tetramer-lactose complex is assumed to be the ccdB expression concentration.

Based on this, we obtain the following equation:

$$
\text{Tex} + \text{IPTG} \xrightleftharpoons[{k_{\text{L}_{\text{1}}}'}]{k_{\text{L}_{\text{1}}}} \text{TI}
\tag{L1}
$$

Reaction L1 describes the formation of the tetramer-lactose complex, where $\text{Tet}$ represents the concentration of the tetramer, $\text{IPTG}$ represents the concentration of lactose, ${k_{\text{L}_{\text{1}}}}$ represents the binding rate, ${k_{\text{L}_{\text{1}}}'}$ represents the dissociation rate, and $\text{TI}$ represents the tetramer-lactose complex.

Applying the law of mass action, we can convert it into a system of ODE:

$$
\dfrac{d\text{TI}}{dt} = {k_{\text{L}_{\text{1}}}} \text{IPTG} - {k_{\text{L}_{\text{1}}}'} \text{TI}
\tag{L2}
$$

L2 relates the ccdB expression rate $\text{TI}$ to the changes in $\text{IPTG}$.

Using the QSSA, we can simplify the equation as follows:

$$
0 = \dfrac{d\text{TI}}{dt} = {k_{\text{L}_{\text{1}}}} \text{IPTG} - {k_{\text{L}_{\text{1}}}'} \text{TI}
$$
$$
\text{TI} = \dfrac{k_{\text{L}_{\text{1}}} \text{IPTG}}{k_{\text{L}_{\text{1}}}'}
\tag{L3}
$$

This is the equation for the ccdB Reactions model.

## III. Parameters

We measured the survival of Mbc at different concentrations of lactose and time used as a reference for the effect of ccdB. Detailed table and instructions can be seen [here.](../project/results.md#vi-determination-of-suicide-efficiency)

## IV. Reference

[^first]: GEMS-Taiwan Toxin-Antitoxin Model iGEM2022 (https://2022.igem.wiki/gems-taiwan/toxinantitoxin)
